@@ -39,7 +39,7 @@ def write(fields, filename, fmt='NETCDF3_CLASSIC', overwrite=True,
           least_significant_digit=None, endian='native', compress=0,
           fletcher32=False, no_shuffle=False, datatype=None,
           single=False, double=False, reference_datetime=None,
-          variable_attributes=None):
+          variable_attributes=None, HDF_chunks=None):
     '''Write fields to a CF-netCDF or CFA-netCDF file.
     
 NetCDF dimension and variable names will be taken from variables'
@@ -218,7 +218,6 @@ and auxiliary coordinate roles for different data variables.
     if least_significant_digit and fmt in ('CFA3', 'CFA4'):
         raise ValueError("Can't truncate data variables in {0} format file".format(fmt))
 
-
     # ----------------------------------------------------------------
     # Set up non-global attributes
     # ----------------------------------------------------------------
@@ -392,7 +391,28 @@ and auxiliary coordinate roles for different data variables.
     # ---------------------------------------------------------------
     # ---------------------------------------------------------------
     for f in fields:
+
+        # Set HDF chunking
+        org_chunks = f.HDF_chunks(HDF_chunks)
+        default_chunks = f.HDF_chunks()
+        chunks = org_chunks.copy()
+        shape = f.shape
+        for i, size in org_chunks.iteritems():
+            if size is None:
+                size = default_chunks[i]
+            dim_size = shape[i]
+            if size is None or size > dim_size:
+                size = dim_size
+            chunks[i] = size
+        #--- End: for
+        f.HDF_chunks(chunks)
+
+        # Write the field
         _write_a_field(f, g=g)
+
+        # Reset HDF chunking
+        f.HDF_chunks(org_chunks)
+
         if verbose:
             for e in f:            
                 print repr(e)
@@ -1744,6 +1764,11 @@ created. The ``seen`` dictionary is updated for *cfvar*.
         else:
             lsd = None
 
+        # Set HDF chunk sizes
+        chunksizes = [size for i, size in sorted(cfvar.HDF_chunks().items())]
+        if chunksizes == [None] * cfvar.ndim:
+            chunksizes = None
+
         try:
             g['nc'][ncvar] = g['netcdf'].createVariable(
                 ncvar,
@@ -1752,12 +1777,14 @@ created. The ``seen`` dictionary is updated for *cfvar*.
                 fill_value=fill_value,
                 least_significant_digit=lsd,
                 endian=g['endian'],
-                **g['compression'])
+                chunksizes=chunksizes,
+                **g['compression']
+            )
         except (TypeError, RuntimeError):
             raise TypeError(
-"Can't write data type {0!r} (from {1!r}) to a {2} file. Use a netCDF4 format or use the 'single' or `datatype' parameters or change the datatype before writing".format(
+"Can't write data type {0!r} (from {1!r}) to a {2} file. Use a netCDF4 format or use the 'single' or 'datatype' parameters or change the datatype before writing".format(
     datatype, cfvar, g['netcdf'].file_format))
-
+            
         _write_attributes(g['nc'][ncvar], netcdf_attrs)
 
         #-------------------------------------------------------------
