@@ -1296,7 +1296,7 @@ False
 
 '''
         try:
-            return not cf.Data(1, 'day') % self.duration
+            return not Data(1, 'day') % self.duration
         except ValueError:
             return False
 #--- End: class
