@@ -1501,8 +1501,8 @@ The reference date-time of reference time units.
                 return origin
         #--- End: if
 
-        raise AttributeError("'%s' has no attribute 'reftime'" %
-                             self.__class__.__name__)
+        raise AttributeError(
+            "{0!r} has no attribute 'reftime'".format(self.__class__.__name__))
     #--- End: def
 
     # ----------------------------------------------------------------
